@@ -107,9 +107,9 @@ static guint signals[LAST_SIGNAL];
 GType
 ags_audio_file_get_type()
 {
-  static volatile gsize g_define_type_id__volatile = 0;
+  static gsize g_define_type_id__static = 0;
 
-  if(g_once_init_enter (&g_define_type_id__volatile)){
+  if(g_once_init_enter(&g_define_type_id__static)){
     GType ags_type_audio_file = 0;
 
     static const GTypeInfo ags_audio_file_info = {
@@ -139,10 +139,10 @@ ags_audio_file_get_type()
 				AGS_TYPE_CONNECTABLE,
 				&ags_connectable_interface_info);
 
-    g_once_init_leave(&g_define_type_id__volatile, ags_type_audio_file);
+    g_once_init_leave(&g_define_type_id__static, ags_type_audio_file);
   }
 
-  return g_define_type_id__volatile;
+  return(g_define_type_id__static);
 }
 
 void
